coffrify_flutter library

Classes

CoffrifyFlutter
Lazily-initialised Coffrify singleton with optional secure storage.
CoffrifyImage
Widget that renders the first file of a Coffrify transfer as an image.
CoffrifyProvider
Inherited widget that exposes a Coffrify instance to descendants via Coffrify.of(context).